@@ -140,7 +140,7 @@ def upload_to_blob(table):
     create_dir(tmp_path)
 
     table.df.to_csv(
-        full_path_to_file, index=False, sep="^", quotechar='"', line_terminator=os.linesep
+        full_path_to_file, index=False, sep="^", quotechar='"', line_terminator="\n"
     )  # export file to staging
 
     logging.debug(f"start uploading blob {table.name}...")
